tka package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tka.data
   tka.external_models

Submodules
----------

tka.utils module
----------------

.. automodule:: tka.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: tka
   :members:
   :undoc-members:
   :show-inheritance:
